@@ -1,10 +1,11 @@
+## no critic (Modules::ProhibitMultiplePackages)
 package DateTime::Infinite;
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.36';
+our $VERSION = '1.46';
 
 use DateTime;
 use DateTime::TimeZone;
@@ -12,6 +13,7 @@ use DateTime::TimeZone;
 use base qw(DateTime);
 
 foreach my $m (qw( set set_time_zone truncate )) {
+    ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no strict 'refs';
     *{"DateTime::Infinite::$m"} = sub { return $_[0] };
 }
@@ -19,6 +21,7 @@ foreach my $m (qw( set set_time_zone truncate )) {
 sub is_finite   {0}
 sub is_infinite {1}
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _rd2ymd {
     return $_[2] ? ( $_[1] ) x 7 : ( $_[1] ) x 3;
 }
@@ -51,20 +54,22 @@ sub hour_12_0 {
     return $_[0]->_infinity_string;
 }
 
-sub iso8601 {
+sub datetime {
     return $_[0]->_infinity_string;
 }
 
-sub _stringify {
+sub stringify {
     return $_[0]->_infinity_string;
 }
 
 sub _infinity_string {
     return $_[0]->{utc_rd_days} == DateTime::INFINITY
-        ? DateTime::INFINITY . ''
-        : DateTime::NEG_INFINITY . '';
+        ? DateTime::INFINITY . q{}
+        : DateTime::NEG_INFINITY . q{};
 }
 
+sub _week_values { [ $_[0]->{utc_rd_days}, $_[0]->{utc_rd_days} ] }
+
 sub STORABLE_freeze {return}
 sub STORABLE_thaw   {return}
 
@@ -164,6 +169,7 @@ my @methods = qw(
 );
 
 for my $meth (@methods) {
+    ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no strict 'refs';
     *{$meth} = sub {undef};
 }
@@ -179,6 +185,7 @@ sub prefers_24_hour_time {
 
 our $AUTOLOAD;
 
+## no critic (ClassHierarchies::ProhibitAutoloading)
 sub AUTOLOAD {
     my $self = shift;
 
@@ -207,7 +214,7 @@ DateTime::Infinite - Infinite past and future DateTime objects
 
 =head1 VERSION
 
-version 1.36
+version 1.46
 
 =head1 SYNOPSIS
 
@@ -256,24 +263,30 @@ on Win32. This may be a problem with this code, Perl, or Win32's IEEE
 math implementation. Either way, the module may not be well-behaved
 on Win32 operating systems.
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime>
-(or L<bug-datetime@rt.cpan.org|mailto:bug-datetime@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime.pm/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime can be found at L<https://github.com/houseabsolute/DateTime.pm>.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2003 - 2018 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
